@@ -1,3 +1,4 @@
+import json
 import asyncio
 import hashlib
 import logging
@@ -323,18 +324,20 @@ class AxonApi(s_cell.CellApi, s_share.Share):  # type: ignore
         await self._reqUserAllowed(('axon', 'has'))
         return await self.cell.hashset(sha256)
 
-    async def hashes(self, offs):
+    async def hashes(self, offs, wait=False, timeout=None):
         '''
         Yield hash rows for files that exist in the Axon in added order starting at an offset.
 
         Args:
             offs (int): The index offset.
+            wait (boolean): Wait for new results and yield them in realtime.
+            timeout (int): Max time to wait for new results.
 
         Yields:
             (int, (bytes, int)): An index offset and the file SHA-256 and size.
         '''
         await self._reqUserAllowed(('axon', 'has'))
-        async for item in self.cell.hashes(offs):
+        async for item in self.cell.hashes(offs, wait=wait, timeout=timeout):
             yield item
 
     async def history(self, tick, tock=None):
@@ -523,6 +526,34 @@ class AxonApi(s_cell.CellApi, s_share.Share):  # type: ignore
         async for item in self.cell.iterMpkFile(sha256):
             yield item
 
+    async def readlines(self, sha256):
+        '''
+        Yield lines from a multi-line text file in the axon.
+
+        Args:
+            sha256 (bytes): The sha256 hash of the file.
+
+        Yields:
+            str: Lines of text
+        '''
+        await self._reqUserAllowed(('axon', 'get'))
+        async for item in self.cell.readlines(sha256):
+            yield item
+
+    async def jsonlines(self, sha256):
+        '''
+        Yield JSON objects from JSONL (JSON lines) file.
+
+        Args:
+            sha256 (bytes): The sha256 hash of the file.
+
+        Yields:
+            object: Decoded JSON objects.
+        '''
+        await self._reqUserAllowed(('axon', 'get'))
+        async for item in self.cell.jsonlines(sha256):
+            yield item
+
 class Axon(s_cell.Cell):
 
     cellapi = AxonApi
@@ -650,12 +681,14 @@ class Axon(s_cell.Cell):
         for item in self.axonhist.carve(tick, tock=tock):
             yield item
 
-    async def hashes(self, offs):
+    async def hashes(self, offs, wait=False, timeout=None):
         '''
         Yield hash rows for files that exist in the Axon in added order starting at an offset.
 
         Args:
             offs (int): The index offset.
+            wait (boolean): Wait for new results and yield them in realtime.
+            timeout (int): Max time to wait for new results.
 
         Yields:
             (int, (bytes, int)): An index offset and the file SHA-256 and size.
@@ -663,7 +696,7 @@ class Axon(s_cell.Cell):
         Note:
             If the same hash was deleted and then added back, the same hash will be yielded twice.
         '''
-        for item in self.axonseqn.iter(offs):
+        async for item in self.axonseqn.aiter(offs, wait=wait, timeout=timeout):
             if self.axonslab.has(item[1][0], db=self.sizes):
                 yield item
             await asyncio.sleep(0)
@@ -952,6 +985,36 @@ class Axon(s_cell.Cell):
             for _, item in unpk.feed(byts):
                 yield item
 
+    async def readlines(self, sha256):
+        remain = ''
+        async for byts in self.get(s_common.uhex(sha256)):
+            text = remain + byts.decode()
+
+            lines = text.split('\n')
+            if len(lines) == 1:
+                remain = text
+                continue
+
+            remain = lines[-1]
+            for line in lines[:-1]:
+                yield line
+
+        if remain:
+            yield remain
+
+    async def jsonlines(self, sha256):
+        async for line in self.readlines(sha256):
+            line = line.strip()
+            if not line:
+                continue
+
+            try:
+                yield json.loads(line)
+            except json.JSONDecodeError as e:
+                logger.exception(f'Bad json line encountered for {sha256}')
+                raise s_exc.BadJsonText(mesg=f'Bad json line encountered while processing {sha256}, ({e})',
+                                        sha256=sha256) from None
+
     async def wput(self, sha256, url, params=None, headers=None, method='PUT', ssl=True, timeout=None, filename=None, filemime=None):
         '''
         Stream a blob from the axon as the body of an HTTP request.
