@@ -14,7 +14,9 @@ def woot(x, y=30):
 class DynDepsTest(s_t_utils.SynTest):
 
     def test_dyndeps_dynmod(self):
-        self.none(s_dyndeps.getDynMod('- -'))
+        with self.getLoggerStream('synapse.lib.dyndeps', 'Failed to import "- -"') as stream:
+            self.none(s_dyndeps.getDynMod('- -'))
+            self.true(stream.wait(1))
         self.nn(s_dyndeps.getDynMod('sys'))
 
     def test_dyndeps_dynloc(self):
